@@ -1,5 +1,5 @@
 (* 
- * $Id: uq_engines.ml 1049 2006-12-17 14:48:01Z gerd $
+ * $Id: uq_engines.ml 1121 2007-05-06 18:20:37Z gerd $
  *)
 
 
@@ -1441,6 +1441,7 @@ let anyway ~finally f arg =
 type fd_style =
     [ `Read_write
     | `Recv_send of Unix.sockaddr
+    | `Recv_send_implied
     | `Recvfrom_sendto
     ]
 
@@ -1461,6 +1462,12 @@ class socket_multiplex_controller
       | Unix.Unix_error(Unix.ENOTSOCK,_,_) -> 
 	  (* fd is not a socket *)
 	  `Read_write
+      | Unix.Unix_error((Unix.EAFNOSUPPORT|Unix.EOPNOTSUPP),_,_) ->
+	  (* EAFNOSUPPORT is returned by the OCaml runtime for unexpected
+             socket names. EOPNOTSUPP is the official SUS code for 
+             sockets lacking an address.
+           *)
+	  `Recv_send_implied
   in
 
 object(self)
@@ -1491,7 +1498,7 @@ object(self)
 
   method received_from =
     match rcvd_from with
-      | None -> failwith "#received_from: Nothing received yet"
+      | None -> failwith "#received_from: Nothing received yet, or unknown address"
       | Some a -> a
 
   method send_to a =
@@ -1680,6 +1687,8 @@ object(self)
 			      let n = Unix.recv fd s pos len [] in
 			      rcvd_from <- Some a;
 			      n
+			  | `Recv_send_implied ->
+			      Unix.recv fd s pos len []
 			  | `Recvfrom_sendto ->
 			      let (n, a) = Unix.recvfrom fd s pos len [] in
 			      rcvd_from <- Some a;
@@ -1746,7 +1755,7 @@ object(self)
 		    try
 		      let n = 
 			match fd_style with
-			  | `Recv_send _ ->
+			  | `Recv_send _ | `Recv_send_implied ->
 			      Unix.send fd s pos len []
 			  | `Recvfrom_sendto ->
 			      ( match send_to with
@@ -2304,11 +2313,13 @@ object (self)
 		  let s = Unix.socket Unix.PF_UNIX stype 0 in
 		  setup_socket s stype (Unix.ADDR_UNIX path) opts;
 	      | `Sock_inet(stype, addr, port) ->
-		  let s = Unix.socket Unix.PF_INET stype 0 in
+		  let dom = Netsys.domain_of_inet_addr addr in
+		  let s = Unix.socket dom stype 0 in
 		  setup_socket s stype (Unix.ADDR_INET(addr,port)) opts;
 	      | `Sock_inet_byname(stype, name, port) ->
 		  let addr = addr_of_name name in
-		  let s = Unix.socket Unix.PF_INET stype 0 in
+		  let dom = Netsys.domain_of_inet_addr addr in
+		  let s = Unix.socket dom stype 0 in
 		  setup_socket s stype (Unix.ADDR_INET(addr,port)) opts;
 	  in
 	  let conn_eng =
@@ -2546,7 +2557,8 @@ object(self)
 		    Unix.listen s opts.lstn_backlog;
 		    s
 		| `Sock_inet(stype, addr, port) ->
-		    let s = Unix.socket Unix.PF_INET stype 0 in
+		    let dom = Netsys.domain_of_inet_addr addr in
+		    let s = Unix.socket dom stype 0 in
 		    Unix.set_nonblock s;
 		    if opts.lstn_reuseaddr then 
 		      Unix.setsockopt s Unix.SO_REUSEADDR true;
@@ -2555,7 +2567,8 @@ object(self)
 		    s
 		| `Sock_inet_byname(stype, name, port) ->
 		    let addr = addr_of_name name in
-		    let s = Unix.socket Unix.PF_INET stype 0 in
+		    let dom = Netsys.domain_of_inet_addr addr in
+		    let s = Unix.socket dom stype 0 in
 		    Unix.set_nonblock s;
 		    if opts.lstn_reuseaddr then 
 		      Unix.setsockopt s Unix.SO_REUSEADDR true;
@@ -2596,6 +2609,7 @@ let listener ?proxy lstnaddr ues =
 type datagram_type =
     [ `Unix_dgram
     | `Inet_udp
+    | `Inet6_udp
     ]
 ;;
 
@@ -2677,6 +2691,7 @@ let datagram_provider ?proxy dgtype ues =
 	  match dgtype with
 	      `Unix_dgram -> (Unix.PF_UNIX, Unix.SOCK_DGRAM, 0)
 	    | `Inet_udp   -> (Unix.PF_INET, Unix.SOCK_DGRAM, 0)
+	    | `Inet6_udp  -> (Unix.PF_INET6, Unix.SOCK_DGRAM, 0)
 	in
 	let wsock =
 	  new direct_datagram_socket dgtype (sdom,stype,sproto) in
