@@ -1,8 +1,10 @@
-(* $Id: neturl.ml,v 2.4 2005/01/26 11:51:40 stolpmann Exp $
+(* $Id: neturl.ml 1062 2006-12-17 20:17:36Z gerd $
  * ----------------------------------------------------------------------
  *
  *)
 
+open Printf
+
 exception Malformed_URL
 
 type url_syntax_option =
@@ -271,7 +273,7 @@ let ( <=> ) (a:bool) b = ( a = b );;  (* equivalence *)
 
 let url_syntax_is_valid syn =
   let recognized x = x <> Url_part_not_recognized in
-  let not_recognized x = x = Url_part_not_recognized in
+  let _not_recognized x = x = Url_part_not_recognized in
   (recognized syn.url_enable_password   => recognized syn.url_enable_user) &&
   (recognized syn.url_enable_user_param => recognized syn.url_enable_user) &&
   (recognized syn.url_enable_port       => recognized syn.url_enable_host) &&
@@ -603,7 +605,6 @@ let modify_url
       url 
   =
 
-  let encode = Netencoding.Url.encode ~plus:true in
   let enc ?(plus=false) x =
     if encoded then
       x
@@ -711,24 +712,19 @@ let modify_url
 	(* This is illegal. *)
 	raise Malformed_URL;
     | "" :: p' ->
-	(* The path is absolute: always ok *)
-	()
+	(* The path is absolute: ensure there is no double slash with host *)
+	( match url'.url_path with
+	    | "" :: "" :: _ ->
+		(* Double slash at beginning of path: Only allowed we have
+                 * a host name!
+                 *)
+		if host = None then raise Malformed_URL
+	    | _ -> ()
+	)
     | _ ->
 	(* The path is relative: there must not be a host *)
 	if url'.url_host <> None then raise Malformed_URL;
   end;
-  begin match url'.url_path with
-      _ :: rest ->              (* "//" ambiguity *)
-	begin match List.rev rest with
-	    _ :: rest' -> 
-	      if List.exists (fun p -> p = "") rest' then
-		raise Malformed_URL;
-	  | [] ->
-	      ()
-	end
-    | [] ->
-	()
-  end;
   (* Cache that the URL is valid: *)
   url'.url_validity <- true;
 
@@ -1284,6 +1280,20 @@ let url_of_string url_syntax s =
 ;;
 
 
+
+let problem_re = Pcre.regexp "[ <>\"{}|\\\\^\\[\\]`]"
+
+let fixup_url_string =
+  Netstring_pcre.global_substitute 
+    problem_re
+    (fun m s ->
+       sprintf "%%%02x" (Char.code s.[Netstring_pcre.match_beginning m]))
+;;
+
+  
+
+
+
 let parse_url ?(schemes = common_url_syntax)
               ?base_syntax
 	      ?(accept_8bits = false)
@@ -1473,7 +1483,10 @@ let apply_relative_url baseurl relurl =
 	    let rec change_path basepath =
 	      match basepath with
 		| [] ->
-		    relpath
+		    if baseurl.url_host = None then
+		      relpath
+		    else
+		      "" :: relpath
 		| [ "" ] ->
 		    "" :: relpath
 		| [ x ] ->
@@ -1694,53 +1707,3 @@ let local_path_of_file_url u =
     | (None, _, _) ->
 	failwith "Neturl.local_path_of_file_url: Missing scheme (relative URL?)"
 ;;
-
-
-(* ======================================================================
- * History:
- * 
- * $Log: neturl.ml,v $
- * Revision 2.4  2005/01/26 11:51:40  stolpmann
- * 	Fix: Encoding of spaces in URLs. In previous versions, the plus
- * sign was handled as equal to %20 everywhere in the URL. This is wrong.
- * The plus sign has only a special meaning in the query part of the URL.
- *
- * Revision 2.3  2004/07/18 16:36:24  stolpmann
- * 	New: Neturl.file_url_of_local_path, local_path_of_file_url.
- * 	URL updates according to RFC 2396.
- *
- * Revision 2.2  2004/07/12 22:57:01  stolpmann
- * 	Added: parse_url, ensure_absolute_url
- * 	Support for userparam.
- * 	Syntax can prevent relative URLs.
- * 	A lot of new syntaxes (pop, imap, ...)
- *
- * Revision 2.1  2001/09/14 14:22:34  stolpmann
- * 	Initial revision (sourceforge)
- *
- *
- * ======================================================================
- * Revision 1.6  2001/08/30 19:46:16  gerd
- * 	Follow-up.
- *
- * Revision 1.5  2001/08/21 21:33:16  gerd
- * 	Fix: apply_relative_url works now for the case that the
- * baseurl is absolute with path = "/", and relurl is relative, e.g.
- * baseurl = file://host/, relurl = file.
- *
- * Revision 1.4  2000/07/04 21:50:51  gerd
- * 	Fixed typo.
- *
- * Revision 1.3  2000/06/26 22:57:49  gerd
- * 	Change: The record 'url_syntax' has an additional component
- * 'url_accepts_8bits'. Setting this option to 'true' causes that
- * the bytes >= 0x80 are no longer rejected.
- *
- * Revision 1.2  2000/06/25 19:39:48  gerd
- * 	Lots of Bugfixes.
- *
- * Revision 1.1  2000/06/24 20:19:59  gerd
- * 	Initial revision.
- *
- * 
- *)
